@@ -333,6 +333,8 @@ namespace xt
         template <class ST>
         bool broadcast_shape(ST& s, bool reuse_cache = false) const;
 
+        constexpr layout_type layout() const noexcept;
+
     private:
 
         container_type m_data;
@@ -445,6 +447,8 @@ namespace xt
         template <class E>
         xfixed_adaptor& operator=(const xexpression<E>& e);
 
+        constexpr layout_type layout() const noexcept;
+
     private:
 
         container_closure_type m_data;
@@ -597,6 +601,12 @@ namespace xt
         return xt::broadcast_shape(m_shape, shape);
     }
 
+    template <class ET, class S, layout_type L, class Tag>
+    constexpr layout_type xfixed_container<ET, S, L, Tag>::layout() const noexcept
+    {
+        return base_type::static_layout;
+    }
+
     template <class ET, class S, layout_type L, class Tag>
     inline auto xfixed_container<ET, S, L, Tag>::data_impl() noexcept -> container_type&
     {
@@ -720,6 +730,12 @@ namespace xt
         return m_data;
     }
 
+    template <class EC, class S, layout_type L, class Tag>
+    constexpr layout_type xfixed_adaptor<EC, S, L, Tag>::layout() const noexcept
+    {
+        return base_type::static_layout;
+    }
+
     template <class EC, class S, layout_type L, class Tag>
     CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, Tag>::shape_impl() const noexcept -> const inner_shape_type&
     {
