@@ -12,8 +12,8 @@
 #include <type_traits>
 #include <utility>
 
-#include "xtl/xoptional.hpp"
-#include "xtl/xoptional_sequence.hpp"
+#include <xtl/xoptional.hpp>
+#include <xtl/xoptional_sequence.hpp>
 
 #include "xarray.hpp"
 #include "xtensor.hpp"
@@ -53,6 +53,82 @@ namespace xt
             }
         };
 
+        template <class T, class Tag>
+        struct split_optional_expression_impl<xscalar<T>, Tag>
+        {
+            using value_expression = xscalar<T>;
+            using flag_expression = xscalar<bool>;
+
+            template <class U>
+            static inline U&& value(U&& arg)
+            {
+                return std::forward<U>(arg);
+            }
+
+            template <class U>
+            static inline flag_expression has_value(U&&)
+            {
+                return xscalar<bool>(true);
+            }
+        };
+
+        template <class T, bool is_const, bool is_ref>
+        struct split_optional_scalar
+        {
+            using raw_value_closure = typename T::value_closure;
+            using raw_flag_closure = typename T::flag_closure;
+            using cst_value_closure = std::conditional_t<is_const,
+                                                         std::add_const_t<raw_value_closure>,
+                                                         raw_value_closure>;
+            using cst_flag_closure = std::conditional_t<is_const,
+                                                        std::add_const_t<raw_flag_closure>,
+                                                        raw_flag_closure>;
+            using value_closure = std::conditional_t<is_ref,
+                                                     std::add_lvalue_reference_t<cst_value_closure>,
+                                                     cst_value_closure>;
+            using flag_closure = std::conditional_t<is_ref,
+                                                    std::add_lvalue_reference_t<cst_flag_closure>,
+                                                    cst_flag_closure>;
+            using value_expression = xscalar<value_closure>;
+            using flag_expression = xscalar<flag_closure>;
+
+            template <class U>
+            static inline value_expression value(U&& arg)
+            {
+                return arg().value();
+            }
+
+            template <class U>
+            static inline flag_expression has_value(U&& arg)
+            {
+                return arg().has_value();
+            }
+        };
+
+        template <class T, class B, class Tag>
+        struct split_optional_expression_impl<xscalar<xtl::xoptional<T, B>>, Tag>
+            : split_optional_scalar<xtl::xoptional<T, B>, false, false>
+        {
+        };
+
+        template <class T, class B, class Tag>
+        struct split_optional_expression_impl<xscalar<xtl::xoptional<T, B>&>, Tag>
+            : split_optional_scalar<xtl::xoptional<T, B>, false, true>
+        {
+        };
+
+        template <class T, class B, class Tag>
+        struct split_optional_expression_impl<xscalar<const xtl::xoptional<T, B>&>, Tag>
+            : split_optional_scalar<xtl::xoptional<T, B>, true, true>
+        {
+        };
+
+        template <class T, class B, class Tag>
+        struct split_optional_expression_impl<xscalar<const xtl::xoptional<T, B>>, Tag>
+            : split_optional_scalar<xtl::xoptional<T, B>, true, false>
+        {
+        };
+
         template <class T>
         struct split_optional_expression_impl<T, xoptional_expression_tag>
         {
@@ -322,12 +398,12 @@ namespace xt
      * xoptional_function implementation *
      *************************************/
 
-     /**
-      * Constructs an xoptional_function applying the specified function to the given
-      * arguments.
-      * @param func the function to apply
-      * @param e the \ref xexpression arguments
-      */
+    /**
+     * Constructs an xoptional_function applying the specified function to the given
+     * arguments.
+     * @param func the function to apply
+     * @param e the \ref xexpression arguments
+     */
     template <class F, class R, class... CT>
     template <class Func, class U>
     inline xoptional_function<F, R, CT...>::xoptional_function(Func&& func, CT... e) noexcept
@@ -352,7 +428,7 @@ namespace xt
     inline auto xoptional_function<F, R, CT...>::value_impl(std::index_sequence<I...>) const -> value_expression
     {
         return value_expression(value_functor(),
-            detail::split_optional_expression<CT>::value(std::forward<CT>(std::get<I>(this->arguments())))...);
+            detail::split_optional_expression<CT>::value(std::get<I>(this->arguments()))...);
     }
 
     template <class F, class R, class... CT>
@@ -360,7 +436,7 @@ namespace xt
     inline auto xoptional_function<F, R, CT...>::has_value_impl(std::index_sequence<I...>) const -> flag_expression
     {
         return flag_expression(flag_functor(),
-            detail::split_optional_expression<CT>::has_value(std::forward<CT>(std::get<I>(this->arguments())))...);
+            detail::split_optional_expression<CT>::has_value(std::get<I>(this->arguments()))...);
     }
 
     /********************************
@@ -417,26 +493,10 @@ namespace xt
         E1& de1 = e1.derived_cast();
         const E2& de2 = e2.derived_cast();
 
-        bool trivial_broadcast = trivial && detail::is_trivial_broadcast(de1, de2);
-        if (trivial_broadcast)
-        {
-            using base_value_type1 = typename std::decay_t<decltype(xt::value(de1))>::value_type;
-            using base_value_type2 = typename std::decay_t<decltype(xt::value(de2))>::value_type;
-            constexpr bool contiguous_layout = E1::contiguous_layout && E2::contiguous_layout;
-            constexpr bool same_type = std::is_same<base_value_type1, base_value_type2>::value;
-            constexpr bool simd_size = xsimd::simd_traits<base_value_type1>::size > 1;
-            constexpr bool forbid_simd = detail::forbid_simd_assign<E2>::value;
-            constexpr bool simd_assign = contiguous_layout && same_type && simd_size && !forbid_simd;
-            decltype(auto) bde1 = xt::value(de1);
-            decltype(auto) hde1 = xt::has_value(de1);
-            trivial_assigner<simd_assign>::run(bde1, xt::value(de2));
-            trivial_assigner<false>::run(hde1, xt::has_value(de2));
-        }
-        else
-        {
-            data_assigner<E1, E2, default_assignable_layout(E1::static_layout)> assigner(de1, de2);
-            assigner.run();
-        }
+        decltype(auto) bde1 = xt::value(de1);
+        decltype(auto) hde1 = xt::has_value(de1);
+        xexpression_assigner_base<xtensor_expression_tag>::assign_data(bde1, xt::value(de2), trivial);
+        xexpression_assigner_base<xtensor_expression_tag>::assign_data(hde1, xt::has_value(de2), trivial);
     }
 }
 
